@@ -1,9 +1,9 @@
-/* Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+/* Copyright 2002-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -17,35 +17,14 @@
 #ifndef SSL_TOOLKIT_COMPAT_H
 #define SSL_TOOLKIT_COMPAT_H
 
-/**
- * @file ssl_toolkit_compat.h 
- * @brief this header file provides a compatiblity layer
- *        between OpenSSL and RSA sslc
- *
- * @defgroup MOD_SSL_TOOLKIT Toolkit
- * @ingroup  MOD_SSL
- * @{
+/*
+ * this header file provides a compatiblity layer
+ * between OpenSSL and RSA sslc
  */
 
-#ifdef HAVE_OPENSSL
+#ifdef OPENSSL_VERSION_NUMBER
 
-/** OpenSSL headers */
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include <openssl/x509.h>
-#include <openssl/pem.h>
-#include <openssl/crypto.h>
-#include <openssl/evp.h>
-#include <openssl/rand.h>
-#include <openssl/x509v3.h>
-/** Avoid tripping over an engine build installed globally and detected
- * when the user points at an explicit non-engine flavor of OpenSSL
- */
-#if defined(HAVE_OPENSSL_ENGINE_H) && defined(HAVE_ENGINE_INIT)
-#include <openssl/engine.h>
-#endif
-
-/**
+/*
  * rsa sslc uses incomplete types for most structures
  * so we macroize for OpenSSL those which cannot be dereferenced
  * using the same sames as the sslc functions
@@ -71,7 +50,7 @@
 #define SSL_SESSION_get_session_id(s)      (s->session_id)
 #define SSL_SESSION_get_session_id_length(s) (s->session_id_length)
 
-/**
+/*
  * Support for retrieving/overriding states
  */
 #ifndef SSL_get_state
@@ -83,36 +62,13 @@
 #define MODSSL_BIO_CB_ARG_TYPE const char
 #define MODSSL_CRYPTO_CB_ARG_TYPE const char
 #if (OPENSSL_VERSION_NUMBER < 0x00907000)
-# define MODSSL_INFO_CB_ARG_TYPE SSL*
+#define MODSSL_INFO_CB_ARG_TYPE SSL*
 #else
-# define MODSSL_INFO_CB_ARG_TYPE const SSL*
+#define MODSSL_INFO_CB_ARG_TYPE const SSL*
 #endif
 #define MODSSL_CLIENT_CERT_CB_ARG_TYPE X509
 #define MODSSL_PCHAR_CAST
 
-/** ...shifting sands of openssl... */
-#if (OPENSSL_VERSION_NUMBER >= 0x0090707f)
-# define MODSSL_D2I_SSL_SESSION_CONST    const
-# define MODSSL_SSL_CIPHER_CONST         const
-#else
-# define MODSSL_D2I_SSL_SESSION_CONST
-# define MODSSL_SSL_CIPHER_CONST
-#endif
-
-#if (OPENSSL_VERSION_NUMBER >= 0x00908000)
-# define MODSSL_D2I_PrivateKey_CONST const
-# define MODSSL_D2I_X509_CONST const
-#else
-# define MODSSL_D2I_PrivateKey_CONST
-# define MODSSL_D2I_X509_CONST
-#endif
-
-#if (OPENSSL_VERSION_NUMBER >= 0x00909000)
-# define MODSSL_SSL_METHOD_CONST const
-#else
-# define MODSSL_SSL_METHOD_CONST
-#endif
-
 #define modssl_X509_verify_cert X509_verify_cert
 
 typedef int (modssl_read_bio_cb_fn)(char*,int,int,void*);
@@ -139,34 +95,16 @@ typedef int (modssl_read_bio_cb_fn)(char*,int,int,void*);
 
 #define HAVE_SSL_RAND_EGD /* since 9.5.1 */
 
+#ifdef HAVE_SSL_X509V3_H
 #define HAVE_SSL_X509V3_EXT_d2i
-
-#if (OPENSSL_VERSION_NUMBER >= 0x009080a0) && defined(OPENSSL_FIPS)
-#define HAVE_FIPS
 #endif
 
-#ifndef PEM_F_DEF_CALLBACK
-#ifdef PEM_F_PEM_DEF_CALLBACK
-/** In OpenSSL 0.9.8 PEM_F_DEF_CALLBACK was renamed */
-#define PEM_F_DEF_CALLBACK PEM_F_PEM_DEF_CALLBACK 
-#endif
-#endif
+#elif defined (SSLC_VERSION_NUMBER) /* RSA */
 
-#elif defined(HAVE_SSLC)
-
-#include <bio.h>
-#include <ssl.h>
-#include <err.h>
-#include <x509.h>
-#include <pem.h>
-#include <evp.h>
-#include <objects.h>
-#include <sslc.h>
-
-/** sslc does not support this function, OpenSSL has since 9.5.1 */
+/* sslc does not support this function, OpenSSL has since 9.5.1 */
 #define RAND_status() 1
 
-/** sslc names this function a bit differently */
+/* sslc names this function a bit differently */
 #define CRYPTO_num_locks() CRYPTO_get_num_locks()
 
 #ifndef STACK_OF
@@ -178,9 +116,6 @@ typedef int (modssl_read_bio_cb_fn)(char*,int,int,void*);
 #define MODSSL_INFO_CB_ARG_TYPE SSL*
 #define MODSSL_CLIENT_CERT_CB_ARG_TYPE void
 #define MODSSL_PCHAR_CAST (char *)
-#define MODSSL_D2I_SSL_SESSION_CONST
-#define MODSSL_D2I_PrivateKey_CONST
-#define MODSSL_D2I_X509_CONST
 
 typedef int (modssl_read_bio_cb_fn)(char*,int,int);
 
@@ -196,7 +131,7 @@ typedef int (modssl_read_bio_cb_fn)(char*,int,int);
    PEM_read_bio_PrivateKey(b, k, cb)
 
 #ifndef HAVE_SSL_SET_STATE
-#define SSL_set_state(ssl, state) /** XXX: should throw an error */
+#define SSL_set_state(ssl, state) /* XXX: should throw an error */
 #endif
 
 #define modssl_set_cipher_list(ssl, l) \
@@ -219,13 +154,15 @@ typedef int (modssl_read_bio_cb_fn)(char*,int,int);
 #define modssl_set_verify(ssl, verify, cb) \
     SSL_set_verify(ssl, verify)
 
-#else /** SSLC_VERSION_NUMBER >= 0x2000 */
+#define NO_SSL_X509V3_H
+
+#else /* SSLC_VERSION_NUMBER >= 0x2000 */
 
 #define CRYPTO_malloc_init R_malloc_init
 
 #define EVP_cleanup() 
 
-#endif /** SSLC_VERSION_NUMBER >= 0x2000 */
+#endif /* SSLC_VERSION_NUMBER >= 0x2000 */
 
 typedef void (*modssl_popfree_fn)(char *data);
 
@@ -255,27 +192,23 @@ typedef void (*modssl_popfree_fn)(char *data);
 #define sk_X509_REVOKED_num sk_num
 #define sk_X509_REVOKED_value (X509_REVOKED *)sk_value
 
-#else /** ! HAVE_OPENSSL && ! HAVE_SSLC */
+#else /* ! OPENSSL_VERSION_NUMBER && ! SSLC_VERSION_NUMBER */
 
 #error "Unrecognized SSL Toolkit!"
 
-#endif /* ! HAVE_OPENSSL && ! HAVE_SSLC */
+#endif /* ! OPENSSL_VERSION_NUMBER && ! SSLC_VERSION_NUMBER */
 
 #ifndef modssl_set_verify
 #define modssl_set_verify(ssl, verify, cb) \
     SSL_set_verify(ssl, verify, cb)
 #endif
 
+#ifndef NO_SSL_X509V3_H
+#define HAVE_SSL_X509V3_H
+#endif
+
 #ifndef SSL_SESS_CACHE_NO_INTERNAL
 #define SSL_SESS_CACHE_NO_INTERNAL  SSL_SESS_CACHE_NO_INTERNAL_LOOKUP
 #endif
 
-#ifndef OPENSSL_NO_TLSEXT
-#ifndef SSL_CTRL_SET_TLSEXT_HOSTNAME
-#define OPENSSL_NO_TLSEXT
-#endif
-#endif
-
 #endif /* SSL_TOOLKIT_COMPAT_H */
-
-/** @} */
