@@ -1,9 +1,9 @@
-/* Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -76,42 +76,26 @@ typedef enum {
  * @{
  */
 
-#define APR_FPROT_USETID      0x8000 /**< Set user id */
-#define APR_FPROT_UREAD       0x0400 /**< Read by user */
-#define APR_FPROT_UWRITE      0x0200 /**< Write by user */
-#define APR_FPROT_UEXECUTE    0x0100 /**< Execute by user */
+#define APR_USETID      0x8000 /**< Set user id */
+#define APR_UREAD       0x0400 /**< Read by user */
+#define APR_UWRITE      0x0200 /**< Write by user */
+#define APR_UEXECUTE    0x0100 /**< Execute by user */
 
-#define APR_FPROT_GSETID      0x4000 /**< Set group id */
-#define APR_FPROT_GREAD       0x0040 /**< Read by group */
-#define APR_FPROT_GWRITE      0x0020 /**< Write by group */
-#define APR_FPROT_GEXECUTE    0x0010 /**< Execute by group */
+#define APR_GSETID      0x4000 /**< Set group id */
+#define APR_GREAD       0x0040 /**< Read by group */
+#define APR_GWRITE      0x0020 /**< Write by group */
+#define APR_GEXECUTE    0x0010 /**< Execute by group */
 
-#define APR_FPROT_WSTICKY     0x2000 /**< Sticky bit */
-#define APR_FPROT_WREAD       0x0004 /**< Read by others */
-#define APR_FPROT_WWRITE      0x0002 /**< Write by others */
-#define APR_FPROT_WEXECUTE    0x0001 /**< Execute by others */
+#define APR_WSTICKY     0x2000 /**< Sticky bit */
+#define APR_WREAD       0x0004 /**< Read by others */
+#define APR_WWRITE      0x0002 /**< Write by others */
+#define APR_WEXECUTE    0x0001 /**< Execute by others */
 
-#define APR_FPROT_OS_DEFAULT  0x0FFF /**< use OS's default permissions */
+#define APR_OS_DEFAULT  0x0FFF /**< use OS's default permissions */
 
 /* additional permission flags for apr_file_copy  and apr_file_append */
-#define APR_FPROT_FILE_SOURCE_PERMS 0x1000 /**< Copy source file's permissions */
-    
-/* backcompat */
-#define APR_USETID     APR_FPROT_USETID     /**< @deprecated @see APR_FPROT_USETID     */
-#define APR_UREAD      APR_FPROT_UREAD      /**< @deprecated @see APR_FPROT_UREAD      */
-#define APR_UWRITE     APR_FPROT_UWRITE     /**< @deprecated @see APR_FPROT_UWRITE     */
-#define APR_UEXECUTE   APR_FPROT_UEXECUTE   /**< @deprecated @see APR_FPROT_UEXECUTE   */
-#define APR_GSETID     APR_FPROT_GSETID     /**< @deprecated @see APR_FPROT_GSETID     */
-#define APR_GREAD      APR_FPROT_GREAD      /**< @deprecated @see APR_FPROT_GREAD      */
-#define APR_GWRITE     APR_FPROT_GWRITE     /**< @deprecated @see APR_FPROT_GWRITE     */
-#define APR_GEXECUTE   APR_FPROT_GEXECUTE   /**< @deprecated @see APR_FPROT_GEXECUTE   */
-#define APR_WSTICKY    APR_FPROT_WSTICKY    /**< @deprecated @see APR_FPROT_WSTICKY    */
-#define APR_WREAD      APR_FPROT_WREAD      /**< @deprecated @see APR_FPROT_WREAD      */
-#define APR_WWRITE     APR_FPROT_WWRITE     /**< @deprecated @see APR_FPROT_WWRITE     */
-#define APR_WEXECUTE   APR_FPROT_WEXECUTE   /**< @deprecated @see APR_FPROT_WEXECUTE   */
-#define APR_OS_DEFAULT APR_FPROT_OS_DEFAULT /**< @deprecated @see APR_FPROT_OS_DEFAULT */
-#define APR_FILE_SOURCE_PERMS APR_FPROT_FILE_SOURCE_PERMS /**< @deprecated @see APR_FPROT_FILE_SOURCE_PERMS */
-    
+#define APR_FILE_SOURCE_PERMS 0x1000 /**< Copy source file's permissions */
+
 /** @} */
 
 
@@ -124,25 +108,23 @@ typedef struct apr_dir_t          apr_dir_t;
  */
 typedef apr_int32_t               apr_fileperms_t;
 #if (defined WIN32) || (defined NETWARE)
+/**
+ * Structure for determining the inode of the file.
+ */
+typedef apr_uint64_t              apr_ino_t;
 /**
  * Structure for determining the device the file is on.
  */
 typedef apr_uint32_t              apr_dev_t;
 #else
+/** The inode of the file. */
+typedef ino_t                     apr_ino_t;
 /**
  * Structure for determining the device the file is on.
  */
 typedef dev_t                     apr_dev_t;
 #endif
 
-/* See apr.h.in (.hw or .hnw) for the declaration of apr_ino_t,
- * but as we don't want to break users who author for 1.2.x, we
- * can't present this type until they have included apr_file_info.h
- * where it was originally declared in release 1.2.0.
- * Unmask it for use here.
- */
-#undef apr_ino_t
-
 /**
  * @defgroup apr_file_stat Stat Functions
  * @{
@@ -152,7 +134,7 @@ typedef struct apr_finfo_t        apr_finfo_t;
 
 #define APR_FINFO_LINK   0x00000001 /**< Stat the link not the file itself if it is a link */
 #define APR_FINFO_MTIME  0x00000010 /**< Modification Time */
-#define APR_FINFO_CTIME  0x00000020 /**< Creation or inode-changed time */
+#define APR_FINFO_CTIME  0x00000020 /**< Creation Time */
 #define APR_FINFO_ATIME  0x00000040 /**< Access Time */
 #define APR_FINFO_SIZE   0x00000100 /**< Size of the file */
 #define APR_FINFO_CSIZE  0x00000200 /**< Storage size consumed by the file */
@@ -210,7 +192,7 @@ struct apr_finfo_t {
     apr_time_t atime;
     /** The time the file was last modified */
     apr_time_t mtime;
-    /** The time the file was created, or the inode was last changed */
+    /** The time the file was last changed */
     apr_time_t ctime;
     /** The pathname of the file (possibly unrooted) */
     const char *fname;
@@ -226,17 +208,26 @@ struct apr_finfo_t {
  * @param finfo Where to store the information about the file, which is
  * never touched if the call fails.
  * @param fname The name of the file to stat.
- * @param wanted The desired apr_finfo_t fields, as a bit flag of APR_FINFO_
-                 values 
- * @param pool the pool to use to allocate the new file. 
- *
- * @note If @c APR_INCOMPLETE is returned all the fields in @a finfo may
- *       not be filled in, and you need to check the @c finfo->valid bitmask
- *       to verify that what you're looking for is there.
+ * @param wanted The desired apr_finfo_t fields, as a bit flag of APR_FINFO_ values 
+ * @param cont the pool to use to allocate the new file. 
  */ 
 APR_DECLARE(apr_status_t) apr_stat(apr_finfo_t *finfo, const char *fname,
-                                   apr_int32_t wanted, apr_pool_t *pool);
+                                   apr_int32_t wanted, apr_pool_t *cont);
 
+/**
+ * get the specified file's stats.  The file is specified by filename, 
+ * instead of using a pre-opened file.  If the file is a symlink, this function
+ * will get the stats for the symlink not the file the symlink refers to.
+ * @param finfo Where to store the information about the file, which is
+ * never touched if the call fails.
+ * @param fname The name of the file to stat.
+ * @param wanted The desired apr_finfo_t fields, as a bit flag of APR_FINFO_ values 
+ * @param cont the pool to use to allocate the new file. 
+ * @deprecated This function is deprecated, it's equivalent to calling apr_stat with 
+ * the wanted flag value APR_FINFO_LINK
+ */ 
+APR_DECLARE(apr_status_t) apr_lstat(apr_finfo_t *finfo, const char *fname,
+                                    apr_int32_t wanted, apr_pool_t *cont);
 /** @} */
 /**
  * @defgroup apr_dir Directory Manipulation Functions
@@ -247,11 +238,11 @@ APR_DECLARE(apr_status_t) apr_stat(apr_finfo_t *finfo, const char *fname,
  * Open the specified directory.
  * @param new_dir The opened directory descriptor.
  * @param dirname The full path to the directory (use / on all systems)
- * @param pool The pool to use.
+ * @param cont The pool to use.
  */                        
 APR_DECLARE(apr_status_t) apr_dir_open(apr_dir_t **new_dir, 
                                        const char *dirname, 
-                                       apr_pool_t *pool);
+                                       apr_pool_t *cont);
 
 /**
  * close the specified directory. 
@@ -262,14 +253,9 @@ APR_DECLARE(apr_status_t) apr_dir_close(apr_dir_t *thedir);
 /**
  * Read the next entry from the specified directory. 
  * @param finfo the file info structure and filled in by apr_dir_read
- * @param wanted The desired apr_finfo_t fields, as a bit flag of APR_FINFO_
-                 values 
+ * @param wanted The desired apr_finfo_t fields, as a bit flag of APR_FINFO_ values 
  * @param thedir the directory descriptor returned from apr_dir_open
  * @remark No ordering is guaranteed for the entries read.
- *
- * @note If @c APR_INCOMPLETE is returned all the fields in @a finfo may
- *       not be filled in, and you need to check the @c finfo->valid bitmask
- *       to verify that what you're looking for is there.
  */                        
 APR_DECLARE(apr_status_t) apr_dir_read(apr_finfo_t *finfo, apr_int32_t wanted,
                                        apr_dir_t *thedir);
