@@ -1,9 +1,10 @@
-/* Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+#include <stdio.h>
+/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -38,10 +39,6 @@
 #include <strings.h>
 #endif
 
-#if (APR_POOL_DEBUG || defined(MAKE_TABLE_PROFILE)) && APR_HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
 /*****************************************************************
  * This file contains array and apr_table_t functions only.
  */
@@ -90,11 +87,6 @@ APR_DECLARE(apr_array_header_t *) apr_array_make(apr_pool_t *p,
     return res;
 }
 
-APR_DECLARE(void) apr_array_clear(apr_array_header_t *arr)
-{
-    arr->nelts = 0;
-}
-
 APR_DECLARE(void *) apr_array_pop(apr_array_header_t *arr)
 {
     if (apr_is_empty_array(arr)) {
@@ -342,13 +334,14 @@ struct apr_table_t {
     void *creator;
 #endif
     /* An index to speed up table lookups.  The way this works is:
-     *   - Hash the key into the index:
-     *     - index_first[TABLE_HASH(key)] is the offset within
-     *       the table of the first entry with that key
-     *     - index_last[TABLE_HASH(key)] is the offset within
-     *       the table of the last entry with that key
+     *   - Take the requested key and compute its checksum
+     *   - Hash the checksum into the index:
+     *     - index_first[TABLE_HASH(checksum)] is the offset within
+     *       the table of the first entry with that key checksum
+     *     - index_last[TABLE_HASH(checksum)] is the offset within
+     *       the table of the first entry with that key checksum
      *   - If (and only if) there is no entry in the table whose
-     *     key hashes to index element i, then the i'th bit
+     *     checksum hashes to index element i, then the i'th bit
      *     of index_initialized will be zero.  (Check this before
      *     trying to use index_first[i] or index_last[i]!)
      */
@@ -362,19 +355,13 @@ struct apr_table_t {
  * and table_elts() in alloc.h
  */
 #ifdef MAKE_TABLE_PROFILE
-static apr_table_entry_t *do_table_push(const char *func, apr_table_t *t)
+static apr_table_entry_t *table_push(apr_table_t *t)
 {
     if (t->a.nelts == t->a.nalloc) {
-        fprintf(stderr, "%s: table created by %p hit limit of %u\n",
-                func ? func : "table_push", t->creator, t->a.nalloc);
+        return NULL;
     }
     return (apr_table_entry_t *) apr_array_push_noclear(&t->a);
 }
-#if defined(__GNUC__) && __GNUC__ >= 2
-#define table_push(t) do_table_push(__FUNCTION__, t)
-#else
-#define table_push(t) do_table_push(NULL, t)
-#endif
 #else /* MAKE_TABLE_PROFILE */
 #define table_push(t)	((apr_table_entry_t *) apr_array_push_noclear(&(t)->a))
 #endif /* MAKE_TABLE_PROFILE */
@@ -405,12 +392,12 @@ APR_DECLARE(apr_table_t *) apr_table_copy(apr_pool_t *p, const apr_table_t *t)
 {
     apr_table_t *new = apr_palloc(p, sizeof(apr_table_t));
 
-#if APR_POOL_DEBUG
+#ifdef POOL_DEBUG
     /* we don't copy keys and values, so it's necessary that t->a.pool
      * have a life span at least as long as p
      */
     if (!apr_pool_is_ancestor(t->a.pool, p)) {
-	fprintf(stderr, "apr_table_copy: t's pool is not an ancestor of p\n");
+	fprintf(stderr, "copy_table: t's pool is not an ancestor of p\n");
 	abort();
     }
 #endif
@@ -423,20 +410,6 @@ APR_DECLARE(apr_table_t *) apr_table_copy(apr_pool_t *p, const apr_table_t *t)
     return new;
 }
 
-APR_DECLARE(apr_table_t *) apr_table_clone(apr_pool_t *p, const apr_table_t *t)
-{
-    const apr_array_header_t *array = apr_table_elts(t);
-    apr_table_entry_t *elts = (apr_table_entry_t *) array->elts;
-    apr_table_t *new = apr_table_make(p, array->nelts);
-    int i;
-
-    for (i = 0; i < array->nelts; i++) {
-        apr_table_add(new, elts[i].key, elts[i].val);
-    }
-
-    return new;
-}
-
 static void table_reindex(apr_table_t *t)
 {
     int i;
@@ -732,14 +705,14 @@ APR_DECLARE(void) apr_table_mergen(apr_table_t *t, const char *key,
     apr_uint32_t checksum;
     int hash;
 
-#if APR_POOL_DEBUG
+#ifdef POOL_DEBUG
     {
 	if (!apr_pool_is_ancestor(apr_pool_find(key), t->a.pool)) {
-	    fprintf(stderr, "apr_table_mergen: key not in ancestor pool of t\n");
+	    fprintf(stderr, "table_set: key not in ancestor pool of t\n");
 	    abort();
 	}
 	if (!apr_pool_is_ancestor(apr_pool_find(val), t->a.pool)) {
-	    fprintf(stderr, "apr_table_mergen: val not in ancestor pool of t\n");
+	    fprintf(stderr, "table_set: key not in ancestor pool of t\n");
 	    abort();
 	}
     }
@@ -801,14 +774,14 @@ APR_DECLARE(void) apr_table_addn(apr_table_t *t, const char *key,
     apr_uint32_t checksum;
     int hash;
 
-#if APR_POOL_DEBUG
+#ifdef POOL_DEBUG
     {
 	if (!apr_pool_is_ancestor(apr_pool_find(key), t->a.pool)) {
-	    fprintf(stderr, "apr_table_addn: key not in ancestor pool of t\n");
+	    fprintf(stderr, "table_set: key not in ancestor pool of t\n");
 	    abort();
 	}
 	if (!apr_pool_is_ancestor(apr_pool_find(val), t->a.pool)) {
-	    fprintf(stderr, "apr_table_addn: val not in ancestor pool of t\n");
+	    fprintf(stderr, "table_set: key not in ancestor pool of t\n");
 	    abort();
 	}
     }
@@ -833,19 +806,19 @@ APR_DECLARE(apr_table_t *) apr_table_overlay(apr_pool_t *p,
 {
     apr_table_t *res;
 
-#if APR_POOL_DEBUG
+#ifdef POOL_DEBUG
     /* we don't copy keys and values, so it's necessary that
      * overlay->a.pool and base->a.pool have a life span at least
      * as long as p
      */
     if (!apr_pool_is_ancestor(overlay->a.pool, p)) {
 	fprintf(stderr,
-		"apr_table_overlay: overlay's pool is not an ancestor of p\n");
+		"overlay_tables: overlay's pool is not an ancestor of p\n");
 	abort();
     }
     if (!apr_pool_is_ancestor(base->a.pool, p)) {
 	fprintf(stderr,
-		"apr_table_overlay: base's pool is not an ancestor of p\n");
+		"overlay_tables: base's pool is not an ancestor of p\n");
 	abort();
     }
 #endif
@@ -987,16 +960,15 @@ APR_DECLARE(int) apr_table_vdo(apr_table_do_callback_fn_t *comp,
 }
 
 static apr_table_entry_t **table_mergesort(apr_pool_t *pool,
-                                           apr_table_entry_t **values, 
-                                           apr_size_t n)
+                                           apr_table_entry_t **values, int n)
 {
     /* Bottom-up mergesort, based on design in Sedgewick's "Algorithms
      * in C," chapter 8
      */
     apr_table_entry_t **values_tmp =
         (apr_table_entry_t **)apr_palloc(pool, n * sizeof(apr_table_entry_t*));
-    apr_size_t i;
-    apr_size_t blocksize;
+    int i;
+    int blocksize;
 
     /* First pass: sort pairs of elements (blocksize=1) */
     for (i = 0; i + 1 < n; i += 2) {
@@ -1011,7 +983,7 @@ static apr_table_entry_t **table_mergesort(apr_pool_t *pool,
     blocksize = 2;
     while (blocksize < n) {
         apr_table_entry_t **dst = values_tmp;
-        apr_size_t next_start;
+        int next_start;
         apr_table_entry_t **swap;
 
         /* Merge consecutive pairs blocks of the next blocksize.
@@ -1021,10 +993,10 @@ static apr_table_entry_t **table_mergesort(apr_pool_t *pool,
         for (next_start = 0; next_start + blocksize < n;
              next_start += (blocksize + blocksize)) {
 
-            apr_size_t block1_start = next_start;
-            apr_size_t block2_start = block1_start + blocksize;
-            apr_size_t block1_end = block2_start;
-            apr_size_t block2_end = block2_start + blocksize;
+            int block1_start = next_start;
+            int block2_start = block1_start + blocksize;
+            int block1_end = block2_start;
+            int block2_end = block2_start + blocksize;
             if (block2_end > n) {
                 /* The last block may be smaller than blocksize */
                 block2_end = n;
@@ -1181,7 +1153,7 @@ APR_DECLARE(void) apr_table_compress(apr_table_t *t, unsigned flags)
                 *dst++ = *src;
             }
         } while (++src < last_elt);
-        t->a.nelts -= (int)(last_elt - dst);
+        t->a.nelts -= (last_elt - dst);
     }
 
     table_reindex(t);
@@ -1216,18 +1188,18 @@ static void apr_table_cat(apr_table_t *t, const apr_table_t *s)
 APR_DECLARE(void) apr_table_overlap(apr_table_t *a, const apr_table_t *b,
 				    unsigned flags)
 {
-    if (a->a.nelts + b->a.nelts == 0) {
+    const int m = a->a.nelts;
+    const int n = b->a.nelts;
+    apr_pool_t *p = b->a.pool;
+
+    if (m + n == 0) {
         return;
     }
 
-#if APR_POOL_DEBUG
-    /* Since the keys and values are not copied, it's required that
-     * b->a.pool has a lifetime at least as long as a->a.pool. */
-    if (!apr_pool_is_ancestor(b->a.pool, a->a.pool)) {
-        fprintf(stderr, "apr_table_overlap: b's pool is not an ancestor of a's\n");
-        abort();
+    /* copy (extend) a using b's pool */
+    if (a->a.pool != p) {
+        make_array_core(&a->a, p, m+n, sizeof(apr_table_entry_t), 0);
     }
-#endif
 
     apr_table_cat(a, b);
 
